@@ -22,7 +22,7 @@
 # Created:     27/12/2012
 # -----------------------------------------------------------------------------
 import os,sys,re
-import shutil
+import shutil, glob
 import datetime
 import hashlib
 import base64
@@ -228,6 +228,9 @@ def remove(files):
     remove
     """
     res=True
+    if isinstance(files, str) and "*" in files:
+        files = glob.glob(files)
+
     for item in listify(files):
         try:
             if os.path.isfile(item):
@@ -239,6 +242,23 @@ def remove(files):
             res=False
     return res
 
+def movefile(src,dst):
+    try:
+        if os.path.exists(src):
+            shutil.move(src,dst)
+    except Exception as ex:
+        print("Exception:",ex)
+
+def move( src, dst, env = {}):
+    src = sformat(src,env)
+    dst = sformat(dst,env)
+    if "*" in src:
+        for filesrc in glob.glob(src):
+            movefile(filesrc,dst)
+    else:
+        movefile(src, dst)
+
+
 def mkdirs(pathname):
     """
     mkdirs - create a folder
